/*
 * This file is a part of Winix
 * and is not publicly distributed
 * 
 * Copyright (c) 2010, Tomasz Sowa
 * All rights reserved.
 * 
 */
 
#include "reply.h"
#include "functions/functions.h"
#include "core/misc.h"
#include "core/plugin.h"
#include "pluginmsg.h"



namespace Thread
{

Reply::Reply()
{
	fun.url = L"reply";
}



void Reply::SetTDb(TDb * ptdb)
{
	tdb = ptdb;
}


void Reply::SetThreadInfo(ThreadInfo * pthread_info)
{
	thread_info = pthread_info;
}


bool Reply::HasAccess()
{
	if( !cur->request->is_item )
		return false;

	Item * dir = thread_info->FindThreadDir();

	if( !dir || !system->HasWriteAccess(*dir) )
		return false;

	plugin.Call(WINIX_PL_THREAD_CAN_USE_REPLY);

	if( plugin.True() > 0 )
		return true;

	if( system->mounts.pmount->type != thread_info->mount_type_thread )
		return false;

return true;
}



void Reply::MakePost()
{
	Item * dir = thread_info->FindThreadDir();

	if( !dir )
	{
		cur->request->status = WINIX_ERR_PERMISSION_DENIED;
		return;
	}

	if( tdb->GetThreadByFileId(cur->request->item.id, thread) != WINIX_ERR_OK )
	{
		thread.Clear();
		thread.file_id = cur->request->item.id;
		tdb->AddThread(thread);
	}

	answer.Clear();
	answer.url = cur->request->item.url;
	answer.url += L"_msg_";
	answer.url += Toa(thread.replies + 1);
	answer.subject = answer.url;
	functions->ReadItem(answer, Item::file);
	functions->SetUser(answer);
	functions->PrepareUrl(answer);
	answer.parent_id  = dir->id;
	answer.privileges = 0644; // !! tymczasowo

	if( functions->CheckAbuse() )
		return;

	cur->request->status = system->AddFile(answer);

	if( cur->request->status == WINIX_ERR_OK )
		cur->request->status = tdb->EditThreadAddItem(cur->request->item.id, answer.id);


	if( cur->request->status == WINIX_ERR_OK )
	{
		log << log2 << "Reply: added an answer in a thread" << logend;
		system->RedirectTo(cur->request->item);
	}
	else
	{
		log << log1 << "Reply: problem with adding an answer, error code: "
			<< cur->request->status << logend;
	}
}




} // namespace
